### Qt5 Libraries
%define major		2
%define libname		%mklibname %{name} %{major}
%define libname_s	%mklibname %{name}-server %{major}
%define devname		%mklibname %{name} -d
### Qt6 Libraries
%define major_qt6	2
%define libname_qt6	%mklibname %{name}-qt6_ %{major_qt6}
%define libname_s_qt6	%mklibname %{name}-server-qt6_ %{major_qt6}
%define devname_qt6	%mklibname %{name}-qt6 -d

%bcond_without	qt5
%bcond_without	qt6

Name:		kdsoap
Version:	2.2.0
Release:	%mkrel 1
Summary:	Qt based client-side and server-side SOAP component
Group:		System/Libraries
# The entire source code is the GPLv3 expect libkdsoap-server which is AGPLv3
License:	GPLv3 and AGPLv3
Url:		https://www.kdab.com/products/kd-soap
Source0:	https://github.com/KDAB/KDSoap/releases/download/%{name}-%{version}/%{name}-%{version}.tar.gz
Patch0:		kdsoap-2.1.1-mkspecs_features-dir.patch

BuildRequires:	cmake
BuildRequires:	pkgconfig(zlib)
### Qt5 build dependencies
%if %{with qt5}
BuildRequires:	cmake(Qt5Core)
BuildRequires:	cmake(Qt5Network)
BuildRequires:	cmake(Qt5Widgets)
BuildRequires:	cmake(Qt5Xml)
%endif
### Qt6 build dependencies
%if %{with qt6}
BuildRequires:	cmake(Qt6Core)
BuildRequires:	cmake(Qt6Network)
BuildRequires:	cmake(Qt6Widgets)
BuildRequires:	cmake(Qt6Xml)
%endif

%description
Qt based client-side and server-side SOAP component.

#------------------------------------------------------------------------------
%if %{with qt5}

%package -n %{libname}
Summary:	Qt based client-side and server-side SOAP component
Group:		System/Libraries

%description -n %{libname}
Qt based client-side and server-side SOAP component.

#------------------------------------------------------------------------------

%package -n %{libname_s}
Summary:	Qt based client-side and server-side SOAP component
Group:		System/Libraries

%description -n %{libname_s}
Qt based client-side and server-side SOAP component.

#------------------------------------------------------------------------------

%package -n %{devname}
Summary:	Development files for the Qt based client-side and server-side SOAP component
Group:		Development/KDE and Qt
Requires:	%{libname} = %{version}-%{release}
Requires:	%{libname_s} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}

%description -n %{devname}
Development files for the Qt based client-side and server-side
SOAP component.
%endif

#------------------------------------------------------------------------------
%if %{with qt6}

%package -n %{libname_qt6}
Summary:	Qt6 based client-side and server-side SOAP component
Group:		System/Libraries

%description -n %{libname_qt6}
Qt 6 based client-side and server-side SOAP component.

#------------------------------------------------------------------------------

%package -n %{libname_s_qt6}
Summary:	Qt6 based client-side and server-side SOAP component
Group:		System/Libraries

%description -n %{libname_s_qt6}
Qt 6 based client-side and server-side SOAP component.

#------------------------------------------------------------------------------

%package -n %{devname_qt6}
Summary:	Development files for the Qt6 based client-side and server-side SOAP component
Group:		Development/KDE and Qt
Requires:	%{libname_qt6} = %{version}-%{release}
Requires:	%{libname_s_qt6} = %{version}-%{release}
Provides:	%{name}-qt6-devel = %{version}-%{release}

%description -n %{devname_qt6}
Development files for the Qt 6 based client-side and server-side
SOAP component.
%endif

#------------------------------------------------------------------------------

%prep
%autosetup -p1

%build
### Build Qt5 ###
%if %{with qt5}
%define _vpath_builddir build-qt5
%cmake
%cmake_build
%endif

### Build Qt6 ###
%if %{with qt6}
%define _vpath_builddir build-qt6
# The two helloworld examples fail to build
%cmake_qt6 -DKDSoap_QT6:BOOL=TRUE -DKDSoap_EXAMPLES:BOOL=FALSE
%cmake_build
%endif

%install
%if %{with qt5}
%define _vpath_builddir build-qt5
%cmake_install
%endif

%if %{with qt6}
%define _vpath_builddir build-qt6
%cmake_install
%endif

%if %{with qt5}
%files -n %{libname}
%doc README.md
%license LICENSES/*
%{_libdir}/libkdsoap.so.%{major}{,.*}

%files -n %{libname_s}
%doc README.md
%license LICENSES/*
%{_libdir}/libkdsoap-server.so.%{major}{,.*}

%files -n %{devname}
%doc %{_docdir}/KDSoap/
%{_bindir}/kdwsdl2cpp
%{_includedir}/KDSoapClient/
%{_includedir}/KDSoapServer/
%{_libdir}/libkdsoap.so
%{_libdir}/libkdsoap-server.so
%{_libdir}/cmake/KDSoap/
%{_qt5_archdatadir}/mkspecs/features/kdsoap.prf
%{_qt5_archdatadir}/mkspecs/modules/qt_KDSoapClient.pri
%{_qt5_archdatadir}/mkspecs/modules/qt_KDSoapServer.pri
%endif

%if %{with qt6}
%files -n %{libname_qt6}
%doc README.md
%license LICENSES/*
%{_libdir}/libkdsoap-qt6.so.%{major_qt6}{,.*}

%files -n %{libname_s_qt6}
%doc README.md
%license LICENSES/*
%{_libdir}/libkdsoap-server-qt6.so.%{major_qt6}{,.*}

%files -n %{devname_qt6}
%doc %{_docdir}/KDSoap-qt6/
%{_bindir}/kdwsdl2cpp-qt6
%{_includedir}/KDSoapClient-Qt6/
%{_includedir}/KDSoapServer-Qt6/
%{_libdir}/libkdsoap-qt6.so
%{_libdir}/libkdsoap-server-qt6.so
%{_libdir}/cmake/KDSoap-qt6/
%{_qt6_archdatadir}/mkspecs/modules/qt_KDSoapClient.pri
%{_qt6_archdatadir}/mkspecs/modules/qt_KDSoapServer.pri
%endif


%changelog
* Mon Jan 15 2024 daviddavid <daviddavid> 2.2.0-1.mga10
+ Revision: 2031345
- new version: 2.2.0

* Tue Oct 24 2023 daviddavid <daviddavid> 2.1.1-2.mga10
+ Revision: 2000715
- add Qt6 support

* Tue Nov 29 2022 daviddavid <daviddavid> 2.1.1-1.mga9
+ Revision: 1912678
- new version: 2.1.1

* Sun Apr 03 2022 umeabot <umeabot> 2.0.0-2.mga9
+ Revision: 1842590
- Mageia 9 Mass Rebuild

* Sun Aug 08 2021 luigiwalser <luigiwalser> 2.0.0-1.mga9
+ Revision: 1740393
- 2.0.0
- library major is now 2

* Thu Dec 24 2020 daviddavid <daviddavid> 1.10.0-1.mga8
+ Revision: 1663441
- new version: 1.10.0

* Thu Dec 17 2020 umeabot <umeabot> 1.9.1-2.mga8
+ Revision: 1658688
- Rebuild for new Qt5

* Wed Oct 21 2020 daviddavid <daviddavid> 1.9.1-1.mga8
+ Revision: 1637524
- new version: 1.9.1

* Sat Apr 18 2020 daviddavid <daviddavid> 1.9.0-2.mga8
+ Revision: 1568795
- split out the kdsoap-server library in his own sub-pkg
- fix libraries pkg name

* Sat Apr 18 2020 daviddavid <daviddavid> 1.9.0-1.mga8
+ Revision: 1568762
- initial package kdsoap

